#!/usr/bin/perl -w -I/usr/sausalito/perl -I.
#$Id: System.pm,v 1.2 2000/08/01 22:10:01 jmayer Exp $
#
# author: Jonathan Mayer <jmayer@cobalt.com>
#
# System class

use CCE;

package System;

sub validate
{
	my $cce = shift;
  my $errors = 0;
  my $re_dotquad = qr/^
  	(([0-9])|([1-9][0-9])|(1[0-9][0-9])|(2[0-4][0-9])|(25[0-5])) \. 
  	(([0-9])|([1-9][0-9])|(1[0-9][0-9])|(2[0-4][0-9])|(25[0-5])) \. 
  	(([0-9])|([1-9][0-9])|(1[0-9][0-9])|(2[0-4][0-9])|(25[0-5])) \. 
  	(([0-9])|([1-9][0-9])|(1[0-9][0-9])|(2[0-4][0-9])|(25[0-5]))
  $/x;
  $errors += $cce->validate('hostname', qr/^[\w\-\.]+$/ );
  $errors += $cce->validate('domainname', qr/^[\w\-\.]+$/ );
  $errors += $cce->validate('eth0_ipaddr', $re_dotquad );
  $errors += $cce->validate('eth0_netmask', $re_dotquad );
  $errors += $cce->validate('eth0_up', qr/.*/ );
  $errors += $cce->validate('eth1_ipaddr', $re_dotquad );
  $errors += $cce->validate('eth1_netmask', $re_dotquad );
  $errors += $cce->validate('eth1_up', qr/.*/ );
  $errors += $cce->validate('gateway', qr/.*/ );
  $errors += $cce->validate('dns_primary', $re_dotquad );
  $errors += $cce->validate('dns_secondary', $re_dotquad );
  $errors += $cce->validate('time_region', qr// );
  $errors += $cce->validate('time_country', qr// );
  $errors += $cce->validate('time_zone', qr// );
  $errors += $cce->validate('sitedef_ipaddr', $re_dotquad );
  $errors += $cce->validate('sitedef_domainname', qr// );
  $errors += $cce->validate('sitedef_quota', qr/^(\d+)$/ );
  $errors += $cce->validate('sitedef_maxusers', qr/^(\d+)$/ );
  $errors += $cce->validate('reboot', qr// );

  # check for excessively large quota
  if ($quota && ($quota > 10240000)) {
	  $cce->baddata(0, 'quota', 'excessivelyLargeQuota', { max => 10240000 } );
    $errors++;
  }

  if ($errors) {
  	$cce->bye('FAIL');
    exit 1;
  }
  return 1;
}

1;
