# $Id: Workgroup.pm,v 1.2 2000/09/12 00:59:54 pbaltz Exp $
# Workgroup.pm
#
# Tools for dealing with workgroups.

package Workgroup;

use CCE;
use FileHandle;

# edit a file, line by line, in a safe way
sub editfile
{
  my $filename = shift;
  my $function = shift;
  
  my $lockfile = $filename;
  
  # save away the file permissions
  my $perms = "";
  if (-f $filename) {
	$perms = (stat($filename))[2] & 07777;
  }

  $lockfile =~ s/[^a-zA-Z0-9\-\.]+/_/g;
  $lockfile = "/var/lock/editlock_" . $lockfile;
  
  # lock the file
  for (my $i = 0; $i < 5; $i++) {
  	last if (!-e $lockfile);
    sleep(1);
  }
  my $fh = new FileHandle(">$lockfile");
  if ($fh) {
  	print $fh $$,"\n";
    $fh->close();
  }
  
  # move file to a backup location
  my $backupfile = $filename . '~';
  unlink($backupfile) if (-e $backupfile);
  if (!link($filename, $backupfile)) {
  	print STDERR "Could not create $backupfile: $!\n";
  	return 0; # fail
  }
  if (!unlink($filename)) {
  	print STDERR "Could not unlink $filename: $!\n";
    return 0; # fail
  }

	# open for reading  
  my $fin = new FileHandle("<$backupfile");
  if (!$fin) {
  	print STDERR "Could not open $backupfile for reading: $!\n";
    return 0;
  }
  
  # open for writing
  my $fout = new FileHandle(">$filename");
  if (!$fout) {
  	print STDERR "Could not open $filename for writing: $!\n";
    return 0;
  }
  
  # process file
  my $ret = &$function($fin, $fout);
  
  # close file handles
  $fout->close();
  $fin->close();
  
  # make sure file permissions are preserved
  if($perms) {
	chmod($perms, $filename);
  }

  # unlock the file
  unlink($lockfile);
  
  # return success
  return $ret;
}
  

# validate the current object
sub validate
{
	my $cce = shift;
  my $errors = 0;

	$errors += $cce->validate('name', qr/^[a-zA-Z0-9\.\-\_]{1,12}$/);
  $errors += $cce->validate('quota', qr/^\d*$/);
  $errors += $cce->validate('members', qr/^(:[a-zA-Z0-9\.\-\_:]*:)?$/);
 # $errors += $cce->validate('enabled', qr//);
  
  if ($errors) {
  	$cce->bye('FAIL');
    exit 1;
  }
	return 0;
}  

1;
